@@ -73,11 +73,7 @@ fn main() -> std::io::Result<()> {
                                                 if bytes_read[byte_index + i] == 0 {
                                                     break;
                                                 }
-                                                if (bytes_read[byte_index + i] as char)
-                                                    .is_ascii_alphanumeric()
-                                                {
-                                                    id.push(bytes_read[byte_index + i] as char);
-                                                }
+                                                id.push(bytes_read[byte_index + i] as char);
                                             }
                                             println!("{} = {:?}", struct_name, id);
                                             byte_index += mem_tlen2 as usize;
