@@ -3,7 +3,7 @@
 //! Print some information about a Blender scene file.
 //! ```shell
 //! $ ./target/release/blend_info -h
-//! blend_info 0.2.2
+//! blend_info 0.2.3
 //! Print some information about a Blender scene file.
 //!
 //! USAGE:
@@ -456,6 +456,11 @@ pub fn calc_mem_tlen(member: &DnaStrMember, type_found: u16) -> u16 {
                     }
                     if numbers.len() == 1 {
                         mem_tlen = (numbers[0] as u16) * mem::size_of::<usize>() as u16;
+                    } else if numbers.len() == 3 {
+                        mem_tlen = (numbers[0] as u16)
+                            * (numbers[1] as u16)
+                            * (numbers[2] as u16)
+                            * mem::size_of::<usize>() as u16;
                     } else {
                         mem_tlen = (numbers[0] as u16)
                             * (numbers[1] as u16)
